%define major		2
%define libname		%mklibname htp %{major}
%define libname_devel	%mklibname htp -d

Summary: 	Intrusion Detection System
Name: 		suricata
Version: 	7.0.1
Release: 	%mkrel 2
License: 	GPLv2+
Group: 		Security
URL: 		https://suricata.io/
Source0: 	https://www.openinfosecfoundation.org/download/%{name}-%{version}.tar.gz
Source1:	https://www.openinfosecfoundation.org/download/%{name}-%{version}.tar.gz.sig
Source3:	suricata.sysconfig
Source4:	suricata.logrotate
Source5:	suricata-tmpfiles.conf
# Irrelevant docs are getting installed, drop them
Patch1: suricata-2.0.9-docs.patch
# Suricata service file needs some options supplied
Patch2: suricata-4.1.1-service.patch
# The default path needs to be fixed up to where Fedora keeps it
Patch4: suricata-5.0.4-geolite-path-fixup.patch
# The log path has an extra '/' at the end
Patch5: suricata-6.0.3-log-path-fixup.patch
BuildRequires:	pkgconfig(yaml-0.1)
BuildRequires:	pkgconfig(libnfnetlink)
BuildRequires:	pkgconfig(libnetfilter_log)
BuildRequires:	pkgconfig(libnetfilter_queue)
BuildRequires:	net2-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pcap-devel
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(libcap-ng)
BuildRequires:	magic-devel
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(nspr)
BuildRequires:	pkgconfig(nss)
BuildRequires:	pkgconfig(libmaxminddb)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(lua)
BuildRequires:	pkgconfig(hiredis)
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	rust
BuildRequires:	cargo
BuildRequires:	python3-yaml
%ifarch x86_64
BuildRequires:	pkgconfig(libhs)
BuildRequires:	clang
BuildRequires:	llvm
BuildRequires:	pkgconfig(libbpf)
%endif
Requires:	python3-yaml

%description
The Suricata Engine is an Open Source Next Generation Intrusion
Detection and Prevention Engine. This engine is not intended to
just replace or emulate the existing tools in the industry, but
will bring new ideas and technologies to the field. This new Engine
supports Multi-threading, Automatic Protocol Detection (IP, TCP,
UDP, ICMP, HTTP, TLS, FTP and SMB! ), Gzip Decompression, Fast IP
Matching and coming soon hardware acceleration on CUDA and OpenCL
GPU cards.

%package	-n 	%{libname}
Summary:        HTP library
Group:          Networking/Other

%description 	-n	%{libname}
none for the moment.

%package	-n	%{libname_devel}
Summary:        HTP library developement
Group:          Networking/Other
Provides:	htp-devel = %{version}-%{release}

%description 	-n	%{libname_devel}
none for the moment.
These are devel files.

%prep
%autosetup -p1

sed -i 's/(datadir)/(sysconfdir)/' etc/Makefile.am
%ifarch x86_64
sed -i 's/-D__KERNEL__/-D__KERNEL__ -D__x86_64__/' ebpf/Makefile.am
%endif

# clear executable bit on lib.rs, this is rust file and should not be marked executable
chmod -x rust/vendor/alloc-no-stdlib/src/lib.rs

%build
autoreconf -fi
export CPPFLAGS=-I..
%configure \
    --disable-static \
    --enable-gccprotect \
    --enable-pie \
    --disable-gccmarch-native \
    --disable-coccinelle \
    --enable-nfqueue \
    --enable-nflog \
    --enable-af-packet \
    --enable-jansson \
    --enable-geoip \
    --enable-lua \
    --enable-hiredis \
    --disable-prelude \
    --enable-rust \
%ifarch x86_64
    --enable-ebpf-build \
    --enable-ebpf \
%endif
    --enable-python

%make_build

%install
%make_install

# Setup etc directory
install -d -m 755 %{buildroot}%{_sysconfdir}/suricata
install -m 644 suricata.yaml %{buildroot}%{_sysconfdir}/suricata
install -m 644 *.config %{buildroot}%{_sysconfdir}/%{name}
install -m 644 etc/*.config %{buildroot}%{_sysconfdir}/%{name}

install -d -m 755 %{buildroot}%{_sysconfdir}/suricata/rules
install -m 644 rules/*.rules %{buildroot}%{_sysconfdir}/%{name}/rules

install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/suricata

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 etc/%{name}.service %{buildroot}%{_unitdir}/%{name}.service

install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 etc/%{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Make logging directory
install -d -m 755 %{buildroot}%{_var}/log/suricata

# drop .la file
rm -f %{buildroot}%{_libdir}/libhtp.la
rm -f %{buildroot}%{_libdir}/libhtp.a
rm -fr %{buildroot}%{_docdir}/%{name}

# Setup suricata-update data directory
install -d -m 755 %{buildroot}%{_var}/lib/%{name}

# Setup tmpdirs
install -d -m 755 %{buildroot}%{_tmpfilesdir}
install -m 644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

cp suricata-update/README.rst doc/suricata-update-README.rst

%py3_shebang_fix %{buildroot}%{_prefix}/lib/suricata/python/suricata/sc/suricatasc.py

%check
make check

%pre
%_pre_useradd suricata %{_var}/log/suricata /sbin/nologin

%post
%_post_service suricata

%preun
%_preun_service suricata

%files
%doc doc/Basic_Setup.txt doc/suricata-update-README.rst
%doc doc/Setting_up_IPSinline_for_Linux.txt
%doc COPYING
%{_bindir}/suricata
%{_bindir}/suricatasc
%{_bindir}/suricatactl
%{_bindir}/suricata-update
%{_datadir}/suricata
%attr(755,suricata,suricata) %dir %{_var}/log/suricata
%attr(755,suricata,suricata) %dir %{_var}/lib/%{name}
%dir %{_sysconfdir}/suricata
%dir %{_sysconfdir}/suricata/rules
%{_unitdir}/suricata.service
%config(noreplace) %{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/suricata/suricata.yaml
%config(noreplace) %{_sysconfdir}/%{name}/*.config
%config(noreplace) %{_sysconfdir}/%{name}/rules/*.rules
%config(noreplace) %{_sysconfdir}/sysconfig/suricata
%config(noreplace) %{_sysconfdir}/logrotate.d/suricata
%{_prefix}/lib/suricata
%{_mandir}/man1/suricata.1*
%{_mandir}/man1/suricatactl-filestore.1*
%{_mandir}/man1/suricatactl.1*
%{_mandir}/man1/suricatasc.1*

%files -n %{libname}
%{_libdir}/libhtp.so.%{major}{,.*}

%files -n %{libname_devel}
%{_includedir}/htp/
%{_libdir}/libhtp.so
%{_libdir}/pkgconfig/htp.pc



%changelog
* Fri Mar 29 2024 daviddavid <daviddavid> 7.0.1-2.mga10
+ Revision: 2053091
- rebuild for new hiredis 1.2.0

* Wed Sep 27 2023 daviddavid <daviddavid> 7.0.1-1.mga10
+ Revision: 1991242
- new version: 7.0.1
- switch to pcre2

* Mon Jun 26 2023 guillomovitch <guillomovitch> 6.0.13-1.mga9
+ Revision: 1963104
- new version 6.0.13

* Thu May 18 2023 guillomovitch <guillomovitch> 6.0.12-1.mga9
+ Revision: 1957160
- new version 6.0.12

* Tue Apr 25 2023 guillomovitch <guillomovitch> 6.0.11-1.mga9
+ Revision: 1954944
- new version 6.0.11

* Thu Mar 16 2023 guillomovitch <guillomovitch> 6.0.10-1.mga9
+ Revision: 1949509
- new version 6.0.10

* Fri Dec 16 2022 guillomovitch <guillomovitch> 6.0.9-1.mga9
+ Revision: 1923669
- new version 6.0.9

* Mon Nov 28 2022 guillomovitch <guillomovitch> 6.0.8-1.mga9
+ Revision: 1912215
- new version 6.0.8

* Sat Sep 03 2022 wally <wally> 6.0.6-2.mga9
+ Revision: 1883677
- rebuild for libbpf with lib major 1

* Thu Jul 14 2022 guillomovitch <guillomovitch> 6.0.6-1.mga9
+ Revision: 1868829
- new version 6.0.6

* Sat Jun 18 2022 guillomovitch <guillomovitch> 6.0.5-2.mga9
+ Revision: 1864806
- add dependency on python3-yaml, for suricata-update (#30375)

* Sun May 08 2022 guillomovitch <guillomovitch> 6.0.5-1.mga9
+ Revision: 1856870
- new version 6.0.5

* Sat Mar 19 2022 guillomovitch <guillomovitch> 6.0.4-4.mga9
+ Revision: 1801610
+ rebuild (emptylog)

* Sun Mar 06 2022 tv <tv> 6.0.4-3.mga9
+ Revision: 1789169
- Rebuild for python-3.10
+ tmb <tmb>
- rebuild for python 3.10

* Sun Nov 28 2021 guillomovitch <guillomovitch> 6.0.4-1.mga9
+ Revision: 1759803
- new version 6.0.4

* Tue Jul 13 2021 guillomovitch <guillomovitch> 6.0.3-1.mga9
+ Revision: 1735948
- new version 6.0.3

* Fri Apr 02 2021 wally <wally> 6.0.2-3.mga9
+ Revision: 1712800
- rebuild for lua 5.4

* Sat Mar 20 2021 guillomovitch <guillomovitch> 6.0.2-2.mga9
+ Revision: 1706234
- rebuild for python 3.9

* Sun Mar 07 2021 guillomovitch <guillomovitch> 6.0.2-1.mga9
+ Revision: 1700497
- new version 6.0.2

* Sun Jan 10 2021 guillomovitch <guillomovitch> 6.0.1-1.mga8
+ Revision: 1670411
- new version 6.0.1

* Sun Dec 13 2020 wally <wally> 6.0.0-2.mga8
+ Revision: 1656443
- fix build with autoconf 2.70

* Tue Oct 27 2020 guillomovitch <guillomovitch> 6.0.0-1.mga8
+ Revision: 1639807
- new version 6.0.0
- disable prelude support, as it breaks compilation
- add missing configuration files

* Fri May 01 2020 guillomovitch <guillomovitch> 5.0.3-1.mga8
+ Revision: 1577495
- new version 5.0.3

* Wed Feb 19 2020 umeabot <umeabot> 5.0.2-2.mga8
+ Revision: 1542749
- Mageia 8 Mass Rebuild

* Sat Feb 15 2020 guillomovitch <guillomovitch> 5.0.2-1.mga8
+ Revision: 1526025
- new version 5.0.2
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jan 06 2020 guillomovitch <guillomovitch> 5.0.1-2.mga8
+ Revision: 1477013
- sync with fedora setup

* Sun Dec 15 2019 guillomovitch <guillomovitch> 5.0.1-1.mga8
+ Revision: 1468079
- new version 5.0.1

* Wed Oct 16 2019 guillomovitch <guillomovitch> 5.0.0-1.mga8
+ Revision: 1454187
- new version 5.0.0

* Sun Oct 13 2019 guillomovitch <guillomovitch> 4.1.5-1.mga8
+ Revision: 1452666
- new version 4.1.5
- use python 3 instead of python 2

* Sat May 11 2019 akien <akien> 4.1.4-2.mga7
+ Revision: 1397297
- Rebuild for bootstrapped i586 rust

* Thu May 02 2019 guillomovitch <guillomovitch> 4.1.4-1.mga7
+ Revision: 1396196
- new version 4.1.4

* Sat Mar 16 2019 guillomovitch <guillomovitch> 4.1.3-1.mga7
+ Revision: 1377961
- new version 4.1.3

* Sun Feb 24 2019 daviddavid <daviddavid> 4.1.2-2.mga7
+ Revision: 1369830
- rebuild for new libprelude 5.0.0

* Thu Dec 27 2018 guillomovitch <guillomovitch> 4.1.2-1.mga7
+ Revision: 1345249
- new version 4.1.2

* Tue Nov 13 2018 guillomovitch <guillomovitch> 4.1.0-1.mga7
+ Revision: 1329828
- new version 4.1.0

* Sun Sep 02 2018 daviddavid <daviddavid> 4.0.5-2.mga7
+ Revision: 1256223
- rebuild for new hyperscan 5.0.0
- disable static libraries

* Thu Aug 02 2018 guillomovitch <guillomovitch> 4.0.5-1.mga7
+ Revision: 1246968
- new version 4.0.5

* Sat Feb 24 2018 guillomovitch <guillomovitch> 4.0.4-1.mga7
+ Revision: 1204878
- new version 4.0.4

* Thu Dec 14 2017 guillomovitch <guillomovitch> 4.0.3-1.mga7
+ Revision: 1182535
- new version 4.0.3

* Tue Oct 24 2017 guillomovitch <guillomovitch> 4.0.1-1.mga7
+ Revision: 1173512
- new version 4.0.1

* Mon Aug 07 2017 guillomovitch <guillomovitch> 4.0.0-4.mga7
+ Revision: 1138465
- use dedicated suricata user

* Sun Jul 30 2017 guillomovitch <guillomovitch> 4.0.0-3.mga7
+ Revision: 1132672
- make rust conditional too, as it doesn't build under i386
- make libhs build dependency conditional, as not available under i586
- new version 4.0.0

* Thu Mar 09 2017 luigiwalser <luigiwalser> 3.2.1-1.mga6
+ Revision: 1090519
- 3.2.1

* Tue Dec 13 2016 guillomovitch <guillomovitch> 3.2-1.mga6
+ Revision: 1074777
- new version 3.2

* Fri Nov 11 2016 guillomovitch <guillomovitch> 3.1.3-1.mga6
+ Revision: 1066352
- new version 3.1.3

* Sun Oct 16 2016 guillomovitch <guillomovitch> 3.1.2-2.mga6
+ Revision: 1061109
- rebuild for new libprelude

* Thu Sep 15 2016 guillomovitch <guillomovitch> 3.1.2-1.mga6
+ Revision: 1053189
- new version 3.1.2

* Tue Aug 30 2016 guillomovitch <guillomovitch> 3.1.1-1.mga6
+ Revision: 1049548
- new version 3.1.1

* Wed Apr 27 2016 guillomovitch <guillomovitch> 3.0.1-1.mga6
+ Revision: 1006981
- new version 3.0.1

* Thu Feb 04 2016 guillomovitch <guillomovitch> 3.0-1.mga6
+ Revision: 934189
- new version 3.0

* Fri Jan 01 2016 guillomovitch <guillomovitch> 2.0.11-1.mga6
+ Revision: 917695
- new version 2.0.11

* Tue Dec 01 2015 guillomovitch <guillomovitch> 2.0.10-1.mga6
+ Revision: 907576
- new version 2.0.10

* Sun Oct 11 2015 guillomovitch <guillomovitch> 2.0.9-1.mga6
+ Revision: 889759
- new version 2.0.8

* Sat Sep 12 2015 fwang <fwang> 2.0.8-2.mga6
+ Revision: 878356
- update file list
- rebuild for new prelude

* Mon May 11 2015 neoclust <neoclust> 2.0.8-1.mga5
+ Revision: 821824
- New version 2.0.8, fixes CVE-2015-0971

* Sun Mar 01 2015 guillomovitch <guillomovitch> 2.0.7-1.mga5
+ Revision: 817225
- new version 2.0.7

* Mon Jan 19 2015 guillomovitch <guillomovitch> 2.0.6-1.mga5
+ Revision: 811523
- new version 2.0.6

* Wed Oct 15 2014 umeabot <umeabot> 2.0.4-2.mga5
+ Revision: 741045
- Second Mageia 5 Mass Rebuild

* Mon Oct 06 2014 guillomovitch <guillomovitch> 2.0.4-1.mga5
+ Revision: 737177
- new version 2.0.4

* Sat Sep 27 2014 tv <tv> 2.0.2-3.mga5
+ Revision: 730410
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.0.2-2.mga5
+ Revision: 689624
- Mageia 5 Mass Rebuild

* Tue Jul 01 2014 pterjan <pterjan> 2.0.2-1.mga5
+ Revision: 641940
- 2.0.2

* Thu Jun 05 2014 guillomovitch <guillomovitch> 2.0.1-1.mga5
+ Revision: 633476
- new version 2.0.1
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Apr 08 2014 guillomovitch <guillomovitch> 2.0-1.mga5
+ Revision: 612887
- new version 2.0

* Thu Dec 19 2013 guillomovitch <guillomovitch> 1.4.7-1.mga4
+ Revision: 558909
- new version 1.4.7

* Tue Oct 22 2013 umeabot <umeabot> 1.4.6-3.mga4
+ Revision: 544657
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4.6-2.mga4
+ Revision: 499898
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Oct 09 2013 dlucio <dlucio> 1.4.6-1.mga4
+ Revision: 494168
- 1.4.6
- filelist fix

* Sat Aug 24 2013 dlucio <dlucio> 1.4.5-2.mga4
+ Revision: 470523
- jansson as BR

* Sat Aug 24 2013 dlucio <dlucio> 1.4.5-1.mga4
+ Revision: 470447
- 1.4.5
- filelist fixed

* Mon Jan 14 2013 umeabot <umeabot> 1.4-2.mga3
+ Revision: 383803
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 16 2012 guillomovitch <guillomovitch> 1.4-1.mga3
+ Revision: 331607
- new version

* Fri Dec 07 2012 guillomovitch <guillomovitch> 1.3.5-1.mga3
+ Revision: 327888
- new version

* Sat Dec 01 2012 fwang <fwang> 1.3.3-2.mga3
+ Revision: 323846
- rebuild for new pcre

* Fri Nov 02 2012 dlucio <dlucio> 1.3.3-1.mga3
+ Revision: 312374
- 1.3.3

* Tue Oct 16 2012 guillomovitch <guillomovitch> 1.3.2-1.mga3
+ Revision: 307166
- new version
- switch to Security group

* Wed Aug 22 2012 guillomovitch <guillomovitch> 1.3.1-1.mga3
+ Revision: 283149
- new version

* Sun Jul 15 2012 dlucio <dlucio> 1.3-2.mga3
+ Revision: 271038
- bump release

* Mon Jul 09 2012 guillomovitch <guillomovitch> 1.3-1.mga3
+ Revision: 269048
- new version
- add systemd support
- drop sysinit support

* Sun Apr 29 2012 colin <colin> 1.2.1-2.mga2
+ Revision: 234233
- Add LSB headers to initscripts (mga#5262)

* Sat Jan 21 2012 guillomovitch <guillomovitch> 1.2.1-1.mga2
+ Revision: 199127
- new version
- fix soname
- fix service handling during post-uninstallation
- no need to rebuild autotools build system
- drop .la file

* Fri Jan 20 2012 dlucio <dlucio> 1.2-1.mga2
+ Revision: 198780
- new BR: magic-devel
+ guillomovitch <guillomovitch>
- new version
- spec cleanup

* Fri Nov 11 2011 dlucio <dlucio> 1.1-1.mga2
+ Revision: 166416
- 1.1
- imported package suricata


* Sat Apr 23 2011 Steve Grubb <sgrubb@redhat.com> 1.0.3-1
- New upstream release

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Nov 10 2010 Steve Grubb <sgrubb@redhat.com> 1.0.2-1
- New upstream release (#651978)

* Thu Jul 01 2010 Steve Grubb <sgrubb@redhat.com> 1.0.0-1
- New upstream release

* Fri May 07 2010 Steve Grubb <sgrubb@redhat.com> 0.9.0-1
- New upstream release

* Tue Apr 20 2010 Steve Grubb <sgrubb@redhat.com> 0.8.2-1
- New upstream release

* Sat Feb 27 2010 Steve Grubb <sgrubb@redhat.com> 0.8.1-1
- Initial packaging

